// Render the Color Legend
export const colorLegend = (selection, props) => {
  // Deconstruct the props argument
  const {
    colorScale,
    itemRadius,
    itemSpacing,
    itemTextPos
  } = props;

  // Create a Group Element
  const groups = selection.selectAll('g')
  	.data(colorScale.domain());
  const groupsEnter = groups
  	.enter().append('g')
  		.attr('class','tick');
  groupsEnter
    .merge(groups)
  		.attr('transform', (d, i) =>
      	`translate(0,${i * itemSpacing})`);
  groups.exit().remove();
  
  // Append Child Elements to the Group
  groupsEnter.append('circle')
  	// Use merge to Update Existing DOM Elements
  	.merge(groups.select('circle'))
  		.attr('r', itemRadius)
      .attr('fill', colorScale);

  // Append Child Elements to the Group
  groupsEnter.append('text')
  		.attr('x',itemTextPos)
  		.attr('dy', 0.32 +'em')
   	// Use merge to Update Existing DOM Elements
  	.merge(groups.select('text'))
  		.text(d => d);
 
}

// Render the Size Legend
export const sizeLegend = (selection, props) => {
    // Deconstruct the props argument
  const {
    sizeScale,
    itemAmount,
    itemFill,
	  itemSpacing,
    itemTextPos
  } = props;
  
  const ticks = sizeScale.ticks(itemAmount)
  	.filter(d => d>0)
  	.reverse();

  // Create a Group Element
  const groups = selection.selectAll('g')
  	.data(ticks);
  const groupsEnter = groups
  	.enter().append('g')
  		.attr('class','tick');
  groupsEnter
    .merge(groups)
  		.attr('transform', (d, i) =>
      	`translate(0,${i * itemSpacing})`);
  groups.exit().remove();
  
  // Append Child Elements to the Group
  groupsEnter.append('circle')
  	// Use merge to Update Existing DOM Elements
  	.merge(groups.select('circle'))
  		.attr('r', sizeScale)
      .attr('fill', itemFill);

  // Append Child Elements to the Group
  groupsEnter.append('text')
  		.attr('x',itemTextPos)
  		.attr('dy', 0.32 +'em')
   	// Use merge to Update Existing DOM Elements
  	.merge(groups.select('text'))
  		.text(d => d);

}
